Learn R Programming

fastadi (version 0.1.1)

fastadi-package: fastadi: Self-Tuning Data Adaptive Matrix Imputation

Description

Implements the AdaptiveImpute matrix completion algorithm of 'Intelligent Initialization and Adaptive Thresholding for Iterative Matrix Completion', <https://amstat.tandfonline.com/doi/abs/10.1080/10618600.2018.1518238>. AdaptiveImpute is useful for embedding sparsely observed matrices, often out performs competing matrix completion algorithms, and self-tunes its hyperparameter, making usage easy.

Arguments

Author

Maintainer: Alex Hayes alexpghayes@gmail.com (ORCID) [copyright holder]

Authors:

  • Juhee Cho

  • Donggyu Kim

  • Karl Rohe

See Also